@@ -2,6 +2,7 @@
 
 #
 # Generated  by generateDS.py.
+# Python 3.7.6 (default, Jan  8 2020, 19:59:22)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -23,70 +24,43 @@
 #   generateds
 #
 
+import os
 import sys
+from lxml import etree as etree_
 
 import anonymous_type2_sup as supermod
 
-etree_ = None
-Verbose_import_ = False
-(
-    XMLParser_import_none, XMLParser_import_lxml,
-    XMLParser_import_elementtree
-) = range(3)
-XMLParser_import_library = None
-try:
-    # lxml
-    from lxml import etree as etree_
-    XMLParser_import_library = XMLParser_import_lxml
-    if Verbose_import_:
-        print("running with lxml.etree")
-except ImportError:
-    try:
-        # cElementTree from Python 2.5+
-        import xml.etree.cElementTree as etree_
-        XMLParser_import_library = XMLParser_import_elementtree
-        if Verbose_import_:
-            print("running with cElementTree on Python 2.5+")
-    except ImportError:
-        try:
-            # ElementTree from Python 2.5+
-            import xml.etree.ElementTree as etree_
-            XMLParser_import_library = XMLParser_import_elementtree
-            if Verbose_import_:
-                print("running with ElementTree on Python 2.5+")
-        except ImportError:
-            try:
-                # normal cElementTree install
-                import cElementTree as etree_
-                XMLParser_import_library = XMLParser_import_elementtree
-                if Verbose_import_:
-                    print("running with cElementTree")
-            except ImportError:
-                try:
-                    # normal ElementTree install
-                    import elementtree.ElementTree as etree_
-                    XMLParser_import_library = XMLParser_import_elementtree
-                    if Verbose_import_:
-                        print("running with ElementTree")
-                except ImportError:
-                    raise ImportError(
-                        "Failed to import ElementTree from any known place")
-
-
-def parsexml_(*args, **kwargs):
-    if (XMLParser_import_library == XMLParser_import_lxml and
-            'parser' not in kwargs):
+def parsexml_(infile, parser=None, **kwargs):
+    if parser is None:
         # Use the lxml ElementTree compatible parser so that, e.g.,
         #   we ignore comments.
-        kwargs['parser'] = etree_.ETCompatXMLParser()
-    doc = etree_.parse(*args, **kwargs)
+        parser = etree_.ETCompatXMLParser()
+    try:
+        if isinstance(infile, os.PathLike):
+            infile = os.path.join(infile)
+    except AttributeError:
+        pass
+    doc = etree_.parse(infile, parser=parser, **kwargs)
     return doc
 
+def parsexmlstring_(instring, parser=None, **kwargs):
+    if parser is None:
+        # Use the lxml ElementTree compatible parser so that, e.g.,
+        #   we ignore comments.
+        try:
+            parser = etree_.ETCompatXMLParser()
+        except AttributeError:
+            # fallback to xml.etree
+            parser = etree_.XMLParser()
+    element = etree_.fromstring(instring, parser=parser, **kwargs)
+    return element
+
 #
 # Globals
 #
 
-ExternalEncoding = 'ascii'
+ExternalEncoding = ''
+SaveElementTreeNode = True
 
 #
 # Data representation classes
@@ -94,31 +68,31 @@ ExternalEncoding = 'ascii'
 
 
 class FooListSub(supermod.FooList):
-    def __init__(self, Foo=None, Bar=None, Baz=None):
-        super(FooListSub, self).__init__(Foo, Bar, Baz, )
+    def __init__(self, Foo=None, Bar=None, Baz=None, **kwargs_):
+        super(FooListSub, self).__init__(Foo, Bar, Baz,  **kwargs_)
 supermod.FooList.subclass = FooListSub
 # end class FooListSub
 
 
-class FooType1Sub(supermod.FooType1):
-    def __init__(self, FooType=None):
-        super(FooType1Sub, self).__init__(FooType, )
-supermod.FooType1.subclass = FooType1Sub
-# end class FooType1Sub
+class FooTypeSub(supermod.FooType):
+    def __init__(self, FooType_member=None, **kwargs_):
+        super(FooTypeSub, self).__init__(FooType_member,  **kwargs_)
+supermod.FooType.subclass = FooTypeSub
+# end class FooTypeSub
 
 
-class BarType2Sub(supermod.BarType2):
-    def __init__(self, BarType=None):
-        super(BarType2Sub, self).__init__(BarType, )
-supermod.BarType2.subclass = BarType2Sub
-# end class BarType2Sub
+class BarTypeSub(supermod.BarType):
+    def __init__(self, BarType_member=None, **kwargs_):
+        super(BarTypeSub, self).__init__(BarType_member,  **kwargs_)
+supermod.BarType.subclass = BarTypeSub
+# end class BarTypeSub
 
 
-class BazType3Sub(supermod.BazType3):
-    def __init__(self, BazType=None):
-        super(BazType3Sub, self).__init__(BazType, )
-supermod.BazType3.subclass = BazType3Sub
-# end class BazType3Sub
+class BazTypeSub(supermod.BazType):
+    def __init__(self, BazType_member=None, **kwargs_):
+        super(BazTypeSub, self).__init__(BazType_member,  **kwargs_)
+supermod.BazType.subclass = BazTypeSub
+# end class BazTypeSub
 
 
 def get_root_tag(node):
@@ -131,7 +105,8 @@ def get_root_tag(node):
 
 
 def parse(inFilename, silence=False):
-    doc = parsexml_(inFilename)
+    parser = None
+    doc = parsexml_(inFilename, parser)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
@@ -140,7 +115,9 @@ def parse(inFilename, silence=False):
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
-    doc = None
+    if not SaveElementTreeNode:
+        doc = None
+        rootNode = None
 ##     if not silence:
 ##         sys.stdout.write('<?xml version="1.0" ?>\n')
 ##         rootObj.export(
@@ -151,7 +128,8 @@ def parse(inFilename, silence=False):
 
 
 def parseEtree(inFilename, silence=False):
-    doc = parsexml_(inFilename)
+    parser = None
+    doc = parsexml_(inFilename, parser)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
@@ -159,11 +137,13 @@ def parseEtree(inFilename, silence=False):
         rootClass = supermod.FooList
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
-    # Enable Python to collect the space used by the DOM.
-    doc = None
     mapping = {}
     rootElement = rootObj.to_etree(None, name_=rootTag, mapping_=mapping)
     reverse_mapping = rootObj.gds_reverse_node_mapping(mapping)
+    # Enable Python to collect the space used by the DOM.
+    if not SaveElementTreeNode:
+        doc = None
+        rootNode = None
 ##     if not silence:
 ##         content = etree_.tostring(
 ##             rootElement, pretty_print=True,
@@ -174,9 +154,12 @@ def parseEtree(inFilename, silence=False):
 
 
 def parseString(inString, silence=False):
-    from StringIO import StringIO
-    doc = parsexml_(StringIO(inString))
-    rootNode = doc.getroot()
+    if sys.version_info.major == 2:
+        from StringIO import StringIO
+    else:
+        from io import BytesIO as StringIO
+    parser = None
+    rootNode= parsexmlstring_(inString, parser)
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
         rootTag = 'FooList'
@@ -184,7 +167,8 @@ def parseString(inString, silence=False):
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
-    doc = None
+    if not SaveElementTreeNode:
+        rootNode = None
 ##     if not silence:
 ##         sys.stdout.write('<?xml version="1.0" ?>\n')
 ##         rootObj.export(
@@ -194,7 +178,8 @@ def parseString(inString, silence=False):
 
 
 def parseLiteral(inFilename, silence=False):
-    doc = parsexml_(inFilename)
+    parser = None
+    doc = parsexml_(inFilename, parser)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
@@ -203,7 +188,9 @@ def parseLiteral(inFilename, silence=False):
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
-    doc = None
+    if not SaveElementTreeNode:
+        doc = None
+        rootNode = None
 ##     if not silence:
 ##         sys.stdout.write('#from anonymous_type2_sup import *\n\n')
 ##         sys.stdout.write('import anonymous_type2_sup as model_\n\n')
@@ -219,7 +206,7 @@ Usage: python ???.py <infilename>
 
 
 def usage():
-    print USAGE_TEXT
+    print(USAGE_TEXT)
     sys.exit(1)
 
 
