@@ -2,6 +2,7 @@
 
 #
 # Generated  by generateDS.py.
+# Python 3.7.6 (default, Jan  8 2020, 19:59:22)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -23,70 +24,43 @@
 #   generateds
 #
 
+import os
 import sys
+from lxml import etree as etree_
 
 import extensions2_sup as supermod
 
-etree_ = None
-Verbose_import_ = False
-(
-    XMLParser_import_none, XMLParser_import_lxml,
-    XMLParser_import_elementtree
-) = range(3)
-XMLParser_import_library = None
-try:
-    # lxml
-    from lxml import etree as etree_
-    XMLParser_import_library = XMLParser_import_lxml
-    if Verbose_import_:
-        print("running with lxml.etree")
-except ImportError:
-    try:
-        # cElementTree from Python 2.5+
-        import xml.etree.cElementTree as etree_
-        XMLParser_import_library = XMLParser_import_elementtree
-        if Verbose_import_:
-            print("running with cElementTree on Python 2.5+")
-    except ImportError:
-        try:
-            # ElementTree from Python 2.5+
-            import xml.etree.ElementTree as etree_
-            XMLParser_import_library = XMLParser_import_elementtree
-            if Verbose_import_:
-                print("running with ElementTree on Python 2.5+")
-        except ImportError:
-            try:
-                # normal cElementTree install
-                import cElementTree as etree_
-                XMLParser_import_library = XMLParser_import_elementtree
-                if Verbose_import_:
-                    print("running with cElementTree")
-            except ImportError:
-                try:
-                    # normal ElementTree install
-                    import elementtree.ElementTree as etree_
-                    XMLParser_import_library = XMLParser_import_elementtree
-                    if Verbose_import_:
-                        print("running with ElementTree")
-                except ImportError:
-                    raise ImportError(
-                        "Failed to import ElementTree from any known place")
-
-
-def parsexml_(*args, **kwargs):
-    if (XMLParser_import_library == XMLParser_import_lxml and
-            'parser' not in kwargs):
+def parsexml_(infile, parser=None, **kwargs):
+    if parser is None:
         # Use the lxml ElementTree compatible parser so that, e.g.,
         #   we ignore comments.
-        kwargs['parser'] = etree_.ETCompatXMLParser()
-    doc = etree_.parse(*args, **kwargs)
+        parser = etree_.ETCompatXMLParser()
+    try:
+        if isinstance(infile, os.PathLike):
+            infile = os.path.join(infile)
+    except AttributeError:
+        pass
+    doc = etree_.parse(infile, parser=parser, **kwargs)
     return doc
 
+def parsexmlstring_(instring, parser=None, **kwargs):
+    if parser is None:
+        # Use the lxml ElementTree compatible parser so that, e.g.,
+        #   we ignore comments.
+        try:
+            parser = etree_.ETCompatXMLParser()
+        except AttributeError:
+            # fallback to xml.etree
+            parser = etree_.XMLParser()
+    element = etree_.fromstring(instring, parser=parser, **kwargs)
+    return element
+
 #
 # Globals
 #
 
-ExternalEncoding = 'ascii'
+ExternalEncoding = ''
+SaveElementTreeNode = True
 
 #
 # Data representation classes
@@ -94,85 +68,85 @@ ExternalEncoding = 'ascii'
 
 
 class SpecialDateSub(supermod.SpecialDate):
-    def __init__(self, SpecialProperty=None, valueOf_=None):
-        super(SpecialDateSub, self).__init__(SpecialProperty, valueOf_, )
+    def __init__(self, SpecialProperty=None, valueOf_=None, **kwargs_):
+        super(SpecialDateSub, self).__init__(SpecialProperty, valueOf_,  **kwargs_)
 supermod.SpecialDate.subclass = SpecialDateSub
 # end class SpecialDateSub
 
 
 class ExtremeDateSub(supermod.ExtremeDate):
-    def __init__(self, ExtremeProperty=None, valueOf_=None):
-        super(ExtremeDateSub, self).__init__(ExtremeProperty, valueOf_, )
+    def __init__(self, ExtremeProperty=None, valueOf_=None, **kwargs_):
+        super(ExtremeDateSub, self).__init__(ExtremeProperty, valueOf_,  **kwargs_)
 supermod.ExtremeDate.subclass = ExtremeDateSub
 # end class ExtremeDateSub
 
 
 class singleExtremeDateSub(supermod.singleExtremeDate):
-    def __init__(self, ExtremeProperty=None, valueOf_=None):
-        super(singleExtremeDateSub, self).__init__(ExtremeProperty, valueOf_, )
+    def __init__(self, ExtremeProperty=None, valueOf_=None, **kwargs_):
+        super(singleExtremeDateSub, self).__init__(ExtremeProperty, valueOf_,  **kwargs_)
 supermod.singleExtremeDate.subclass = singleExtremeDateSub
 # end class singleExtremeDateSub
 
 
 class containerTypeSub(supermod.containerType):
-    def __init__(self, simplefactoid=None, mixedfactoid=None):
-        super(containerTypeSub, self).__init__(simplefactoid, mixedfactoid, )
+    def __init__(self, simplefactoid=None, mixedfactoid=None, **kwargs_):
+        super(containerTypeSub, self).__init__(simplefactoid, mixedfactoid,  **kwargs_)
 supermod.containerType.subclass = containerTypeSub
 # end class containerTypeSub
 
 
 class simpleFactoidTypeSub(supermod.simpleFactoidType):
-    def __init__(self, relation=None):
-        super(simpleFactoidTypeSub, self).__init__(relation, )
+    def __init__(self, relation=None, **kwargs_):
+        super(simpleFactoidTypeSub, self).__init__(relation,  **kwargs_)
 supermod.simpleFactoidType.subclass = simpleFactoidTypeSub
 # end class simpleFactoidTypeSub
 
 
 class mixedFactoidTypeSub(supermod.mixedFactoidType):
-    def __init__(self, relation=None, valueOf_=None, mixedclass_=None, content_=None):
-        super(mixedFactoidTypeSub, self).__init__(relation, valueOf_, mixedclass_, content_, )
+    def __init__(self, relation=None, valueOf_=None, mixedclass_=None, content_=None, **kwargs_):
+        super(mixedFactoidTypeSub, self).__init__(relation, valueOf_, mixedclass_, content_,  **kwargs_)
 supermod.mixedFactoidType.subclass = mixedFactoidTypeSub
 # end class mixedFactoidTypeSub
 
 
 class BaseTypeSub(supermod.BaseType):
-    def __init__(self, BaseProperty1=None, BaseProperty2=None, valueOf_=None, extensiontype_=None):
-        super(BaseTypeSub, self).__init__(BaseProperty1, BaseProperty2, valueOf_, extensiontype_, )
+    def __init__(self, BaseProperty1=None, BaseProperty2=None, valueOf_=None, extensiontype_=None, **kwargs_):
+        super(BaseTypeSub, self).__init__(BaseProperty1, BaseProperty2, valueOf_, extensiontype_,  **kwargs_)
 supermod.BaseType.subclass = BaseTypeSub
 # end class BaseTypeSub
 
 
 class DerivedTypeSub(supermod.DerivedType):
-    def __init__(self, BaseProperty1=None, BaseProperty2=None, DerivedProperty1=None, DerivedProperty2=None, valueOf_=None):
-        super(DerivedTypeSub, self).__init__(BaseProperty1, BaseProperty2, DerivedProperty1, DerivedProperty2, valueOf_, )
+    def __init__(self, BaseProperty1=None, BaseProperty2=None, DerivedProperty1=None, DerivedProperty2=None, valueOf_=None, **kwargs_):
+        super(DerivedTypeSub, self).__init__(BaseProperty1, BaseProperty2, DerivedProperty1, DerivedProperty2, valueOf_,  **kwargs_)
 supermod.DerivedType.subclass = DerivedTypeSub
 # end class DerivedTypeSub
 
 
 class MyIntegerSub(supermod.MyInteger):
-    def __init__(self, MyAttr=None, valueOf_=None):
-        super(MyIntegerSub, self).__init__(MyAttr, valueOf_, )
+    def __init__(self, MyAttr=None, valueOf_=None, **kwargs_):
+        super(MyIntegerSub, self).__init__(MyAttr, valueOf_,  **kwargs_)
 supermod.MyInteger.subclass = MyIntegerSub
 # end class MyIntegerSub
 
 
 class MyBooleanSub(supermod.MyBoolean):
-    def __init__(self, MyAttr=None, valueOf_=None):
-        super(MyBooleanSub, self).__init__(MyAttr, valueOf_, )
+    def __init__(self, MyAttr=None, valueOf_=None, **kwargs_):
+        super(MyBooleanSub, self).__init__(MyAttr, valueOf_,  **kwargs_)
 supermod.MyBoolean.subclass = MyBooleanSub
 # end class MyBooleanSub
 
 
 class MyFloatSub(supermod.MyFloat):
-    def __init__(self, MyAttr=None, valueOf_=None):
-        super(MyFloatSub, self).__init__(MyAttr, valueOf_, )
+    def __init__(self, MyAttr=None, valueOf_=None, **kwargs_):
+        super(MyFloatSub, self).__init__(MyAttr, valueOf_,  **kwargs_)
 supermod.MyFloat.subclass = MyFloatSub
 # end class MyFloatSub
 
 
 class MyDoubleSub(supermod.MyDouble):
-    def __init__(self, MyAttr=None, valueOf_=None):
-        super(MyDoubleSub, self).__init__(MyAttr, valueOf_, )
+    def __init__(self, MyAttr=None, valueOf_=None, **kwargs_):
+        super(MyDoubleSub, self).__init__(MyAttr, valueOf_,  **kwargs_)
 supermod.MyDouble.subclass = MyDoubleSub
 # end class MyDoubleSub
 
@@ -187,7 +161,8 @@ def get_root_tag(node):
 
 
 def parse(inFilename, silence=False):
-    doc = parsexml_(inFilename)
+    parser = None
+    doc = parsexml_(inFilename, parser)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
@@ -196,7 +171,9 @@ def parse(inFilename, silence=False):
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
-    doc = None
+    if not SaveElementTreeNode:
+        doc = None
+        rootNode = None
 ##     if not silence:
 ##         sys.stdout.write('<?xml version="1.0" ?>\n')
 ##         rootObj.export(
@@ -207,7 +184,8 @@ def parse(inFilename, silence=False):
 
 
 def parseEtree(inFilename, silence=False):
-    doc = parsexml_(inFilename)
+    parser = None
+    doc = parsexml_(inFilename, parser)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
@@ -215,11 +193,13 @@ def parseEtree(inFilename, silence=False):
         rootClass = supermod.containerType
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
-    # Enable Python to collect the space used by the DOM.
-    doc = None
     mapping = {}
     rootElement = rootObj.to_etree(None, name_=rootTag, mapping_=mapping)
     reverse_mapping = rootObj.gds_reverse_node_mapping(mapping)
+    # Enable Python to collect the space used by the DOM.
+    if not SaveElementTreeNode:
+        doc = None
+        rootNode = None
 ##     if not silence:
 ##         content = etree_.tostring(
 ##             rootElement, pretty_print=True,
@@ -230,9 +210,12 @@ def parseEtree(inFilename, silence=False):
 
 
 def parseString(inString, silence=False):
-    from StringIO import StringIO
-    doc = parsexml_(StringIO(inString))
-    rootNode = doc.getroot()
+    if sys.version_info.major == 2:
+        from StringIO import StringIO
+    else:
+        from io import BytesIO as StringIO
+    parser = None
+    rootNode= parsexmlstring_(inString, parser)
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
         rootTag = 'containerType'
@@ -240,7 +223,8 @@ def parseString(inString, silence=False):
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
-    doc = None
+    if not SaveElementTreeNode:
+        rootNode = None
 ##     if not silence:
 ##         sys.stdout.write('<?xml version="1.0" ?>\n')
 ##         rootObj.export(
@@ -250,7 +234,8 @@ def parseString(inString, silence=False):
 
 
 def parseLiteral(inFilename, silence=False):
-    doc = parsexml_(inFilename)
+    parser = None
+    doc = parsexml_(inFilename, parser)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
@@ -259,7 +244,9 @@ def parseLiteral(inFilename, silence=False):
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
-    doc = None
+    if not SaveElementTreeNode:
+        doc = None
+        rootNode = None
 ##     if not silence:
 ##         sys.stdout.write('#from extensions2_sup import *\n\n')
 ##         sys.stdout.write('import extensions2_sup as model_\n\n')
@@ -275,7 +262,7 @@ Usage: python ???.py <infilename>
 
 
 def usage():
-    print USAGE_TEXT
+    print(USAGE_TEXT)
     sys.exit(1)
 
 
